# examples

All examples are self-contained, and only require the current version of Dashport to be installed. Use these as jumping off points for your own applications.

- Boilerplate: Basic scripts that just create a Dashport window and some text.
- Layouts: Examples of layouts that can be used with dashport
- Util: Scripts that can be used to troubleshoot your scripts.
- Views: View concepts like scrolling text and panels here.
